﻿using System;

using Xamarin.Forms;
using Syncfusion.SfChart.XForms;
using System.Collections.ObjectModel;
using System.Diagnostics;
using System.Threading.Tasks;

namespace SimpleSample
{
    public class Line : ContentPage
    {
        AbsoluteLayout layout;
        SfChart chart;
        ObservableCollection<ChartDataPoint> Data;

        public Line()
        {
            ScrollView scroll = new ScrollView();

            Data = new ObservableCollection<ChartDataPoint>();
            layout = new AbsoluteLayout() { Padding = new Thickness(5, 15, 5, 5) };

            Data.Add(new ChartDataPoint(new DateTime(2002, 6, 1, 0, 0, 0), 23));
            Data.Add(new ChartDataPoint(new DateTime(2002, 6, 1, 1, 0, 0), 20));
            Data.Add(new ChartDataPoint(new DateTime(2002, 6, 1, 2, 0, 0), 35));
            Data.Add(new ChartDataPoint(new DateTime(2002, 6, 1, 3, 0, 0), 32));
            Data.Add(new ChartDataPoint(new DateTime(2002, 6, 1, 4, 0, 0), 45));
            Data.Add(new ChartDataPoint(new DateTime(2002, 6, 1, 5, 0, 0), 10));
            Data.Add(new ChartDataPoint(new DateTime(2002, 6, 1, 6, 0, 0), 20));
            Data.Add(new ChartDataPoint(new DateTime(2002, 6, 1, 7, 0, 0), 35));
            Data.Add(new ChartDataPoint(new DateTime(2002, 6, 1, 8, 0, 0), 32));
            Data.Add(new ChartDataPoint(new DateTime(2002, 6, 1, 9, 0, 0), 25));
            Data.Add(new ChartDataPoint(new DateTime(2002, 6, 1, 10, 0, 0), 38));

            chart = new SfChart();

            layout.SizeChanged += layout_SizeChanged;
            chart.HeightRequest = 1000;

            CategoryAxis cataxis = new CategoryAxis()
            {
                Interval = 1,
                LabelStyle = new ChartAxisLabelStyle() { LabelFormat = "HH" },
            };
            chart.PrimaryAxis = cataxis;

            NumericalAxis numaxis = new NumericalAxis();
            chart.SecondaryAxis = numaxis;

            var line = new LineSeries
            {
                ItemsSource = Data,
            };

            chart.Series.Add(line);
            layout.Children.Add(chart);

            scroll.Content = layout;
            Content = scroll;

        }

        void layout_SizeChanged(object sender, EventArgs e)
        {
            chart.WidthRequest = layout.Width;
        }

        protected async override void OnAppearing()
        {
            base.OnAppearing();
            await Task.Delay(100);

            for (int i = 0; i < Data.Count; i++)
            {
                double X = chart.ValueToPoint(chart.PrimaryAxis, i);
                double Y = chart.ValueToPoint(chart.SecondaryAxis, Data[i].YValue);

                var img = new Image
                {
                    BackgroundColor = Color.Green,
                    HeightRequest = 15,
                    WidthRequest = 15,
                    Source = Device.OnPlatform(
                        iOS: ImageSource.FromFile("Icon-76.png"),
                        Android: ImageSource.FromFile("icon.png"),
                        WinPhone: ImageSource.FromFile("icon.png"))
                };

                X = Device.OnPlatform(iOS: (X - img.WidthRequest / 2), Android: X, WinPhone: X);
                Y = Device.OnPlatform(iOS: (Y - img.HeightRequest / 2), Android: Y, WinPhone: Y);

                layout.Children.Add(img, new Point(X, Y));
            }
        }
    }
}


